==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/AutomationRulePropertyValuesChangedConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.AutomationRulePropertyValuesChangedConditionArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.AutomationRulePropertyChangedConditionSupportedChangedType
import com.pulumi.azurenative.securityinsights.kotlin.enums.AutomationRulePropertyChangedConditionSupportedPropertyType
import com.pulumi.azurenative.securityinsights.kotlin.enums.AutomationRulePropertyConditionSupportedOperator
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property changeType
 * @property operator
 * @property propertyName
 * @property propertyValues
 */
public data class AutomationRulePropertyValuesChangedConditionArgs(
    public val changeType:
    Output<Either<String, AutomationRulePropertyChangedConditionSupportedChangedType>>? = null,
    public val `operator`: Output<Either<String, AutomationRulePropertyConditionSupportedOperator>>? =
        null,
    public val propertyName:
    Output<Either<String, AutomationRulePropertyChangedConditionSupportedPropertyType>>? = null,
    public val propertyValues: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.AutomationRulePropertyValuesChangedConditionArgs> {
    override fun toJava():
        com.pulumi.azurenative.securityinsights.inputs.AutomationRulePropertyValuesChangedConditionArgs =
        com.pulumi.azurenative.securityinsights.inputs.AutomationRulePropertyValuesChangedConditionArgs.builder()
            .changeType(
                changeType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .`operator`(
                `operator`?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .propertyName(
                propertyName?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .propertyValues(propertyValues?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [AutomationRulePropertyValuesChangedConditionArgs].
 */
@PulumiTagMarker
public class AutomationRulePropertyValuesChangedConditionArgsBuilder internal constructor() {
    private var changeType:
        Output<Either<String, AutomationRulePropertyChangedConditionSupportedChangedType>>? = null

    private var `operator`: Output<Either<String, AutomationRulePropertyConditionSupportedOperator>>? =
        null

    private var propertyName:
        Output<Either<String, AutomationRulePropertyChangedConditionSupportedPropertyType>>? = null

    private var propertyValues: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("bjlfainykcxneido")
    public suspend
    fun changeType(`value`: Output<Either<String, AutomationRulePropertyChangedConditionSupportedChangedType>>) {
        this.changeType = value
    }

    /**
     * @param value
     */
    @JvmName("kkuqtoirnulhavsk")
    public suspend
    fun `operator`(`value`: Output<Either<String, AutomationRulePropertyConditionSupportedOperator>>) {
        this.`operator` = value
    }

    /**
     * @param value
     */
    @JvmName("trstdamxycbxdxnf")
    public suspend
    fun propertyName(`value`: Output<Either<String, AutomationRulePropertyChangedConditionSupportedPropertyType>>) {
        this.propertyName = value
    }

    /**
     * @param value
     */
    @JvmName("croilkgotwmcvihg")
    public suspend fun propertyValues(`value`: Output<List<String>>) {
        this.propertyValues = value
    }

    @JvmName("wivughwmpaaydwpi")
    public suspend fun propertyValues(vararg values: Output<String>) {
        this.propertyValues = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("fpcqhvywgkoifucy")
    public suspend fun propertyValues(values: List<Output<String>>) {
        this.propertyValues = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("bqephykkyuexxfrq")
    public suspend
    fun changeType(`value`: Either<String, AutomationRulePropertyChangedConditionSupportedChangedType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.changeType = mapped
    }

    /**
     * @param value
     */
    @JvmName("qhhifcsnftyvjbqj")
    public fun changeType(`value`: String) {
        val toBeMapped = Either.ofLeft<String,
            AutomationRulePropertyChangedConditionSupportedChangedType,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.changeType = mapped
    }

    /**
     * @param value
     */
    @JvmName("lqpngnfyemygconu")
    public fun changeType(`value`: AutomationRulePropertyChangedConditionSupportedChangedType) {
        val toBeMapped = Either.ofRight<String,
            AutomationRulePropertyChangedConditionSupportedChangedType,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.changeType = mapped
    }

    /**
     * @param value
     */
    @JvmName("vjbhellubtvutjdp")
    public suspend
    fun `operator`(`value`: Either<String, AutomationRulePropertyConditionSupportedOperator>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value
     */
    @JvmName("sjhtksgscxsrfmha")
    public fun `operator`(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AutomationRulePropertyConditionSupportedOperator>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value
     */
    @JvmName("hkoiinjxrvucvxyt")
    public fun `operator`(`value`: AutomationRulePropertyConditionSupportedOperator) {
        val toBeMapped = Either.ofRight<String, AutomationRulePropertyConditionSupportedOperator>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value
     */
    @JvmName("bvahpnqctogphvtb")
    public suspend
    fun propertyName(`value`: Either<String, AutomationRulePropertyChangedConditionSupportedPropertyType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.propertyName = mapped
    }

    /**
     * @param value
     */
    @JvmName("hrfyrrjecgreubqf")
    public fun propertyName(`value`: String) {
        val toBeMapped = Either.ofLeft<String,
            AutomationRulePropertyChangedConditionSupportedPropertyType,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.propertyName = mapped
    }

    /**
     * @param value
     */
    @JvmName("rihudeaqaxbqschf")
    public fun propertyName(`value`: AutomationRulePropertyChangedConditionSupportedPropertyType) {
        val toBeMapped = Either.ofRight<String,
            AutomationRulePropertyChangedConditionSupportedPropertyType,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.propertyName = mapped
    }

    /**
     * @param value
     */
    @JvmName("vdgfuanovpgsdejl")
    public suspend fun propertyValues(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.propertyValues = mapped
    }

    /**
     * @param values
     */
    @JvmName("dkieeypkniegegeo")
    public suspend fun propertyValues(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.propertyValues = mapped
    }

    internal fun build(): AutomationRulePropertyValuesChangedConditionArgs =
        AutomationRulePropertyValuesChangedConditionArgs(
            changeType = changeType,
            `operator` = `operator`,
            propertyName = propertyName,
            propertyValues = propertyValues,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/AutomationRulePropertyValuesChangedConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.AutomationRulePropertyValuesChangedConditionArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.AutomationRulePropertyChangedConditionSupportedChangedType
import com.pulumi.azurenative.securityinsights.kotlin.enums.AutomationRulePropertyChangedConditionSupportedPropertyType
import com.pulumi.azurenative.securityinsights.kotlin.enums.AutomationRulePropertyConditionSupportedOperator
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property changeType
 * @property operator
 * @property propertyName
 * @property propertyValues
 */
public data class AutomationRulePropertyValuesChangedConditionArgs(
    public val changeType:
    Output<Either<String, AutomationRulePropertyChangedConditionSupportedChangedType>>? = null,
    public val `operator`: Output<Either<String, AutomationRulePropertyConditionSupportedOperator>>? =
        null,
    public val propertyName:
    Output<Either<String, AutomationRulePropertyChangedConditionSupportedPropertyType>>? = null,
    public val propertyValues: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.AutomationRulePropertyValuesChangedConditionArgs> {
    override fun toJava():
        com.pulumi.azurenative.securityinsights.inputs.AutomationRulePropertyValuesChangedConditionArgs =
        com.pulumi.azurenative.securityinsights.inputs.AutomationRulePropertyValuesChangedConditionArgs.builder()
            .changeType(
                changeType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .`operator`(
                `operator`?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .propertyName(
                propertyName?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .propertyValues(propertyValues?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [AutomationRulePropertyValuesChangedConditionArgs].
 */
@PulumiTagMarker
public class AutomationRulePropertyValuesChangedConditionArgsBuilder internal constructor() {
    private var changeType:
        Output<Either<String, AutomationRulePropertyChangedConditionSupportedChangedType>>? = null

    private var `operator`: Output<Either<String, AutomationRulePropertyConditionSupportedOperator>>? =
        null

    private var propertyName:
        Output<Either<String, AutomationRulePropertyChangedConditionSupportedPropertyType>>? = null

    private var propertyValues: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("ijmxnielajoylosr")
    public suspend
    fun changeType(`value`: Output<Either<String, AutomationRulePropertyChangedConditionSupportedChangedType>>) {
        this.changeType = value
    }

    /**
     * @param value
     */
    @JvmName("jqfwcrkobduesojc")
    public suspend
    fun `operator`(`value`: Output<Either<String, AutomationRulePropertyConditionSupportedOperator>>) {
        this.`operator` = value
    }

    /**
     * @param value
     */
    @JvmName("awybpxlcsevkyavn")
    public suspend
    fun propertyName(`value`: Output<Either<String, AutomationRulePropertyChangedConditionSupportedPropertyType>>) {
        this.propertyName = value
    }

    /**
     * @param value
     */
    @JvmName("cepyovqfyqodjbba")
    public suspend fun propertyValues(`value`: Output<List<String>>) {
        this.propertyValues = value
    }

    @JvmName("mhqjrldqfusgvmpw")
    public suspend fun propertyValues(vararg values: Output<String>) {
        this.propertyValues = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mrdlrdteabojkufy")
    public suspend fun propertyValues(values: List<Output<String>>) {
        this.propertyValues = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("cawmevmuogfaqnjs")
    public suspend
    fun changeType(`value`: Either<String, AutomationRulePropertyChangedConditionSupportedChangedType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.changeType = mapped
    }

    /**
     * @param value
     */
    @JvmName("ckcpqqblaxrwmanv")
    public fun changeType(`value`: String) {
        val toBeMapped = Either.ofLeft<String,
            AutomationRulePropertyChangedConditionSupportedChangedType,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.changeType = mapped
    }

    /**
     * @param value
     */
    @JvmName("cvbwpojktqfsgrri")
    public fun changeType(`value`: AutomationRulePropertyChangedConditionSupportedChangedType) {
        val toBeMapped = Either.ofRight<String,
            AutomationRulePropertyChangedConditionSupportedChangedType,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.changeType = mapped
    }

    /**
     * @param value
     */
    @JvmName("yvmhgvldpqbisakc")
    public suspend
    fun `operator`(`value`: Either<String, AutomationRulePropertyConditionSupportedOperator>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value
     */
    @JvmName("mkijkqbiunnylldr")
    public fun `operator`(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AutomationRulePropertyConditionSupportedOperator>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value
     */
    @JvmName("fihemxphhpukmgfn")
    public fun `operator`(`value`: AutomationRulePropertyConditionSupportedOperator) {
        val toBeMapped = Either.ofRight<String, AutomationRulePropertyConditionSupportedOperator>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value
     */
    @JvmName("xyuaglqgynupprlb")
    public suspend
    fun propertyName(`value`: Either<String, AutomationRulePropertyChangedConditionSupportedPropertyType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.propertyName = mapped
    }

    /**
     * @param value
     */
    @JvmName("koowejnshthpvbft")
    public fun propertyName(`value`: String) {
        val toBeMapped = Either.ofLeft<String,
            AutomationRulePropertyChangedConditionSupportedPropertyType,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.propertyName = mapped
    }

    /**
     * @param value
     */
    @JvmName("yvybpvaivpgafvon")
    public fun propertyName(`value`: AutomationRulePropertyChangedConditionSupportedPropertyType) {
        val toBeMapped = Either.ofRight<String,
            AutomationRulePropertyChangedConditionSupportedPropertyType,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.propertyName = mapped
    }

    /**
     * @param value
     */
    @JvmName("kylfscrsyvlwdysb")
    public suspend fun propertyValues(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.propertyValues = mapped
    }

    /**
     * @param values
     */
    @JvmName("vtovmqvetmqqarqk")
    public suspend fun propertyValues(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.propertyValues = mapped
    }

    internal fun build(): AutomationRulePropertyValuesChangedConditionArgs =
        AutomationRulePropertyValuesChangedConditionArgs(
            changeType = changeType,
            `operator` = `operator`,
            propertyName = propertyName,
            propertyValues = propertyValues,
        )
}
